@@ -18,15 +18,28 @@ has httptiny => (
 );
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Pinto::Remote::SelfContained::HasHttptiny
+
+=head1 NAME
+
+Pinto::Remote::SelfContained::HasHttptiny
+
 =head1 NAME
 
 Pinto::Remote::SelfContained::HasHttptiny - role providing an HTTP::Tiny instance
 
 =head1 AUTHOR
 
-Aaron Crane, E<lt>arc@cpan.orgE<gt>
+Aaron Crane E<lt>arc@cpan.orgE<gt>, Brad Lhotsky E<lt>brad@divisionbyzero.netE<gt>
 
 =head1 COPYRIGHT
 
