@@ -139,15 +139,28 @@ sub dump {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Pinto::Remote::SelfContained::Request
+
+=head1 NAME
+
+Pinto::Remote::SelfContained::Request
+
 =head1 NAME
 
 Pinto::Remote::SelfContained::Request - request class for HTTP::Tiny
 
 =head1 AUTHOR
 
-Aaron Crane, E<lt>arc@cpan.orgE<gt>
+Aaron Crane E<lt>arc@cpan.orgE<gt>, Brad Lhotsky E<lt>brad@divisionbyzero.netE<gt>
 
 =head1 COPYRIGHT
 
